@@ -124,11 +124,11 @@ class code(object):
     COULD_NOT_GET_PATCH_INFO = 60
     PATCHES_NOT_EXPORTED = 61
     COULD_NOT_TRIM = 62
-    DEBIAN_MULTIPLE_PACKAGES_FOUND = 70
-    DEBIAN_UNRECOGNIZED_BUILD_TYPE = 71
-    DEBIAN_FAILED_TO_LOAD_TEMPLATE = 72
-    DEBIAN_NO_SUCH_ROSDEP_KEY = 73
-    DEBIAN_NO_ROSDEP_KEY_FOR_DISTRO = 74
+    GENERATOR_MULTIPLE_PACKAGES_FOUND = 70
+    GENERATOR_UNRECOGNIZED_BUILD_TYPE = 71
+    GENERATOR_FAILED_TO_LOAD_TEMPLATE = 72
+    GENERATOR_NO_SUCH_ROSDEP_KEY = 73
+    GENERATOR_NO_ROSDEP_KEY_FOR_DISTRO = 74
 
 
 class change_directory(object):
